@@ -23,24 +23,25 @@ package InSilicoSpectro::InSilico::MSMSOutput;
 #  Upper Austria University of Applied Science at Hagenberg
 #  Hauptstrasse 117
 #  A-4232 Hagenberg, Austria
-#  http://www.fhs-hagenberg.ac.at
+#  e-mail: jacques.colinge@fh-hagenberg.at or, alternatively, austrian_olav@yahoo.com
 
 require Exporter;
 
-our (@ISA, @EXPORT, @EXPORT_OK);
+our (@ISA, @EXPORT, @EXPORT_OK, $VERSION);
 @ISA = qw(Exporter);
-@EXPORT = qw(normalizeIntensities annotatePept chooseColorLineNum chooseColorFrag htmlCSS plotLegendOnly );
+@EXPORT = qw(normalizeIntensities annotatePept chooseColorLineNum chooseColorFrag htmlCSS plotLegendOnly getVersion);
 @EXPORT_OK = ();
+$VERSION = 1.0;
 
 use strict;
 use Carp;
 use InSilicoSpectro::InSilico::MassCalculator;
 our $okGD;
 eval{
-  #require fails for autoload results  (bug #4)
-  use GD;
+  require GD;
   $okGD=1;
 };
+
 our %htmlize = ('<'=>'&lt;', '>'=>'&gt;', '&'=>'&amp;', '"'=>'&quot;', "'"=>'&apos;');
 our ($tmpim, $tmpWhite);
 
@@ -1524,7 +1525,7 @@ sub plotSpectrumMatch
     }
     else{
       $fname =~ s/\.$format$//;
-      open(FGD, ">$fname.$format") || croak("Cannot open file [$fname.$format]: $!");
+      open(FGD, ">$fname.$format")|| croak("Cannot open file [$fname.$format]: $!");
       binmode FGD;
       print FGD $im->$format;
       close(FGD);
@@ -2315,6 +2316,10 @@ sub plotLegendOnly
 } # plotLegendOnly
 
 
+sub getVersion{
+  $VERSION;
+}
+
 =head1 EXAMPLES
 
 See programs starting with testMSMSOut in folder InSilicoSpectro/InSilico/test/.
