@@ -50,10 +50,6 @@ A dictionnary holds all the enzymes, based on their key
 
 Returns a list of all the enzymes, sorted by name
 
-=head3 registerModResHandler([\&sub])
-
-get/set a subroutine to be called whenever a new modres is instanciated (for example, register into MassCalaculator
-
 =head1 METHODS
 
 =head3 my $mr=InSilicoSpectro::InSilico::ModRes->new([$h])
@@ -80,22 +76,6 @@ Set if the modif is peptide C/N terminus (or just returns the current status is
 
 Set if the modif is protein C/N terminus (or just returns the current status is no value is passed to the function)
 
-=head3 $mr->seq2pos($seq);
-
-returns an array of position where the modif can appear on sequence $seq.
-
-This array contains
-
-=over 4
-
-=item [-1] if it can be attributed nterm
-
-=item [length $seq] if it can be attributer cterm
-
-=item else, a list of indices, starting at 0 for the first AA of the sequence
-
-=back
-
 =head3 $mr->set($name, $val)
 
 Set an instance paramter.
@@ -110,7 +90,7 @@ return an XML::Twig::Elt object containing the modres
 
 =head1 EXAMPLES
 
-see t/InSilico/tesModRes.pl script
+see Phenyx/InSilico/test/tesModRes.pl script
 
 =head1 SEE ALSO
 
@@ -141,13 +121,12 @@ Alexandre Masselot, www.genebio.com
 =cut
 
 
-our (@ISA, @EXPORT, @EXPORT_OK, $isInit, %dico, %re2Modif);
+our (@ISA, @EXPORT, @EXPORT_OK, $isInit, %dico, %re2Modif, $VERSION);
 @ISA = qw(Exporter);
 
-@EXPORT = qw(&init &getFromDico &getList &getModifFromSprotFT &twig_addModRes &registerModResHandler $isInit);
+@EXPORT = qw(&getVersion &init &getFromDico &getList &getModifFromSprotFT &twig_addModRes);
 @EXPORT_OK = ();
-
-our $rsRegisterModResHandler;
+$VERSION = "0.9";
 
 sub new{
   my $pkg=shift;
@@ -175,7 +154,7 @@ sub new{
 use SelectSaver;
 sub print{
   my ($this, $out)=@_;
-  my $fdOut=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or CORE::die "cannot open [$out]: $!")):\*STDOUT;
+  my $fdOut=(defined $out)?(new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) or die "cannot open [$out]: $!")):\*STDOUT;
   print $fdOut "$this->{name} $this->{delta_monoisotopic}"
 }
 
@@ -276,32 +255,12 @@ sub getList{
 sub getModifFromSprotFT{
   my ($ftmodres)=@_;
   foreach (keys %re2Modif){
-    next unless $_;
     return $re2Modif{$_} if $ftmodres=~/^$_$/i;
   }
   return undef;
 }
 
 
-#--------------------------------- positions
-
-sub seq2pos{
-  my ($this, $seq)=@_;
-  my @pos;
-  my $re=$this->regexp;
-  if($this->nTerm){
-    push @pos, -1 if $seq=~/$re/;
-  }elsif($this->cTerm){
-    push @pos, length $seq if $seq=~/$re/;
-
-  }else{
-    while ($seq=~/$re/g){
-      push @pos, pos($seq)-1;
-    }
-}
-  return @pos;
-}
-
 #--------------------------------- init
 
 use XML::Twig;
@@ -317,7 +276,7 @@ sub init{
 			 );
   if(@listFiles){
     foreach (@listFiles){
-      CORE::die "file [$_] is not readable" unless -r $_;
+      die "file [$_] is not readable" unless -r $_;
       $twig->parsefile($_) or InSilicoSpectro::Utils::io::croakIt "cannot parse [$_]: $!";
     }
   }else{
@@ -387,9 +346,6 @@ sub twig_addModRes{
   }
 
 #  $mr->add2Dico();
-  if(registerModResHandler()){
-    registerModResHandler()->($mr);
-  }
 
 }
 
@@ -399,6 +355,7 @@ sub getXMLTwigElt{
   XML::Twig::Elt->new()->parse("<description>$this->{description}</description>")->paste(last_child=>$el);
   if($this->{site}){
     XML::Twig::Elt->new()->parse("<site><residue>$this->{site}{residue}</residue></site>")->paste(last_child=>$el);
+    
   }else{
     XML::Twig::Elt->new()->parse("<siteRegexp>$this->{regexpStr}</siteRegexp>")->paste(last_child=>$el);
   }
@@ -409,12 +366,9 @@ sub getXMLTwigElt{
   return $el;
 }
 
-sub registerModResHandler{
-  my $sub=shift;
-  if($sub){
-    $rsRegisterModResHandler=$sub;
-  }
-  return $rsRegisterModResHandler;
-}
 # -------------------------------   misc
+sub getVersion{
+  return $VERSION;
+}
+
 return 1;
